@@ -10,7 +10,7 @@ use Carp; # generate better errors with more context
 require 5.005;
 
 use vars qw($VERSION @ISA);
-$VERSION = '2.20';
+$VERSION = '2.21';
 
 
 sub new {
@@ -348,7 +348,7 @@ sub start {
 	    if ( $attr->{'value'} eq __escapeHTML($value->[0])){
 	      shift @$value if ref($value) eq 'ARRAY';
 	      $attr->{selected} = 'selected';
-              $self->{selectSelected} = 1; # remeber that an option tag is selected for this select tag
+              $self->{selectSelected} = 1; # remember that an option tag is selected for this select tag
 	    }
           }
         }
